@@ -14,8 +14,8 @@ class CustomHook(BuildHookInterface):
         if self.target_name not in {"wheel", "install"}:
             return
 
-        from compiler.api.compiler import start as compile_api
-        from compiler.errors.compiler import start as compile_errors
+        from compiler.api.compiler import start as compile_api  # noqa: PLC0415
+        from compiler.errors.compiler import start as compile_errors  # noqa: PLC0415
 
         compile_api()
         compile_errors()
