@@ -1,6 +1,6 @@
 #  Hydrogram - Telegram MTProto API Client Library for Python
 #  Copyright (C) 2017-2023 Dan <https://github.com/delivrance>
-#  Copyright (C) 2023-present Amano LLC <https://amanoteam.com>
+#  Copyright (C) 2023-present Hydrogram <https://hydrogram.org>
 #
 #  This file is part of Hydrogram.
 #
@@ -17,6 +17,8 @@
 #  You should have received a copy of the GNU Lesser General Public License
 #  along with Hydrogram.  If not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import annotations
+
 import asyncio
 import contextlib
 import functools
@@ -24,8 +26,10 @@ import inspect
 import logging
 import os
 import platform
+import random
 import re
 import shutil
+import string
 import sys
 from concurrent.futures.thread import ThreadPoolExecutor
 from datetime import datetime, timedelta
@@ -34,12 +38,13 @@ from importlib import import_module
 from io import BytesIO, StringIO
 from mimetypes import MimeTypes
 from pathlib import Path
-from typing import AsyncGenerator, Callable, List, Optional, Union
+from typing import TYPE_CHECKING, Callable
 
 import hydrogram
 from hydrogram import __license__, __version__, enums, raw, utils
 from hydrogram.crypto import aes
 from hydrogram.errors import (
+    AuthBytesInvalid,
     BadRequest,
     CDNFileHashMismatch,
     ChannelPrivate,
@@ -50,7 +55,7 @@ from hydrogram.handlers.handler import Handler
 from hydrogram.methods import Methods
 from hydrogram.session import Auth, Session
 from hydrogram.storage import BaseStorage, SQLiteStorage
-from hydrogram.types import TermsOfService, User
+from hydrogram.types import ListenerTypes, TermsOfService, User
 from hydrogram.utils import ainput
 
 from .dispatcher import Dispatcher
@@ -59,6 +64,9 @@ from .mime_types import mime_types
 from .parser import Parser
 from .session.internals import MsgId
 
+if TYPE_CHECKING:
+    from collections.abc import AsyncGenerator
+
 log = logging.getLogger(__name__)
 
 
@@ -199,7 +207,7 @@ class Client(Methods):
     WORKDIR = PARENT_DIR
 
     # Interval of seconds in which the updates watchdog will kick in
-    UPDATES_WATCHDOG_INTERVAL = 5 * 60
+    UPDATES_WATCHDOG_INTERVAL = 15 * 60
 
     MAX_CONCURRENT_TRANSMISSIONS = 1
 
@@ -209,28 +217,28 @@ class Client(Methods):
     def __init__(
         self,
         name: str,
-        api_id: Optional[Union[int, str]] = None,
-        api_hash: Optional[str] = None,
+        api_id: int | str | None = None,
+        api_hash: str | None = None,
         app_version: str = APP_VERSION,
         device_model: str = DEVICE_MODEL,
         system_version: str = SYSTEM_VERSION,
         lang_code: str = LANG_CODE,
         ipv6: bool = False,
-        proxy: Optional[dict] = None,
+        proxy: dict | None = None,
         test_mode: bool = False,
-        bot_token: Optional[str] = None,
-        session_string: Optional[str] = None,
-        session_storage_engine: Optional[BaseStorage] = None,
-        in_memory: Optional[bool] = None,
-        phone_number: Optional[str] = None,
-        phone_code: Optional[str] = None,
-        password: Optional[str] = None,
+        bot_token: str | None = None,
+        session_string: str | None = None,
+        session_storage_engine: BaseStorage | None = None,
+        in_memory: bool | None = None,
+        phone_number: str | None = None,
+        phone_code: str | None = None,
+        password: str | None = None,
         workers: int = WORKERS,
         workdir: str = str(WORKDIR),
-        plugins: Optional[dict] = None,
-        parse_mode: "enums.ParseMode" = enums.ParseMode.DEFAULT,
-        no_updates: Optional[bool] = None,
-        takeout: Optional[bool] = None,
+        plugins: dict | None = None,
+        parse_mode: enums.ParseMode = enums.ParseMode.DEFAULT,
+        no_updates: bool | None = None,
+        takeout: bool | None = None,
         sleep_threshold: int = Session.SLEEP_THRESHOLD,
         hide_password: bool = False,
         max_concurrent_transmissions: int = MAX_CONCURRENT_TRANSMISSIONS,
@@ -287,6 +295,7 @@ class Client(Methods):
         self.media_sessions = {}
         self.media_sessions_lock = asyncio.Lock()
 
+        self.file_lock = asyncio.Lock()
         self.save_file_semaphore = asyncio.Semaphore(self.max_concurrent_transmissions)
         self.get_file_semaphore = asyncio.Semaphore(self.max_concurrent_transmissions)
 
@@ -297,7 +306,7 @@ class Client(Methods):
 
         self.disconnect_handler = None
 
-        self.me: Optional[User] = None
+        self.me: User | None = None
 
         self.message_cache = Cache(10000)
 
@@ -309,13 +318,7 @@ class Client(Methods):
         self.last_update_time = datetime.now()
 
         self.loop = asyncio.get_event_loop()
-
-    def __enter__(self):
-        return self.start()
-
-    def __exit__(self, *args):
-        with contextlib.suppress(ConnectionError):
-            self.stop()
+        self.listeners = {listener_type: [] for listener_type in ListenerTypes}
 
     async def __aenter__(self):
         return await self.start()
@@ -460,7 +463,7 @@ class Client(Methods):
 
         return signed_up
 
-    def set_parse_mode(self, parse_mode: Optional["enums.ParseMode"]):
+    def set_parse_mode(self, parse_mode: enums.ParseMode | None):
         """Set the parse mode to be used globally by the client.
 
         When setting the parse mode with this method, all other methods having a *parse_mode* parameter will follow the
@@ -499,7 +502,7 @@ class Client(Methods):
         self.parse_mode = parse_mode
 
     async def fetch_peers(
-        self, peers: List[Union[raw.types.User, raw.types.Chat, raw.types.Channel]]
+        self, peers: list[raw.types.User | raw.types.Chat | raw.types.Channel]
     ) -> bool:
         is_min = False
         parsed_peers = []
@@ -556,12 +559,10 @@ class Client(Methods):
         self.last_update_time = datetime.now()
 
         if isinstance(updates, (raw.types.Updates, raw.types.UpdatesCombined)):
-            is_min = any(
-                (
-                    await self.fetch_peers(updates.users),
-                    await self.fetch_peers(updates.chats),
-                )
-            )
+            is_min = any((
+                await self.fetch_peers(updates.users),
+                await self.fetch_peers(updates.chats),
+            ))
 
             users = {u.id: u for u in updates.users}
             chats = {c.id: c for c in updates.chats}
@@ -617,17 +618,15 @@ class Client(Methods):
             )
 
             if diff.new_messages:
-                self.dispatcher.updates_queue.put_nowait(
-                    (
-                        raw.types.UpdateNewMessage(
-                            message=diff.new_messages[0],
-                            pts=updates.pts,
-                            pts_count=updates.pts_count,
-                        ),
-                        {u.id: u for u in diff.users},
-                        {c.id: c for c in diff.chats},
-                    )
-                )
+                self.dispatcher.updates_queue.put_nowait((
+                    raw.types.UpdateNewMessage(
+                        message=diff.new_messages[0],
+                        pts=updates.pts,
+                        pts_count=updates.pts_count,
+                    ),
+                    {u.id: u for u in diff.users},
+                    {c.id: c for c in diff.chats},
+                ))
             elif diff.other_updates:  # The other_updates list can be empty
                 self.dispatcher.updates_queue.put_nowait((diff.other_updates[0], {}, {}))
         elif isinstance(updates, raw.types.UpdateShort):
@@ -638,20 +637,18 @@ class Client(Methods):
     async def load_session(self):
         await self.storage.open()
 
-        session_empty = any(
-            [
-                await self.storage.test_mode() is None,
-                await self.storage.auth_key() is None,
-                await self.storage.user_id() is None,
-                await self.storage.is_bot() is None,
-            ]
-        )
+        session_empty = any([
+            await self.storage.test_mode() is None,
+            await self.storage.auth_key() is None,
+            await self.storage.user_id() is None,
+            await self.storage.is_bot() is None,
+        ])
 
         if session_empty:
             if not self.api_id or not self.api_hash:
                 raise AttributeError(
                     "The API key is required for new authorizations. "
-                    "More info: https://hydrogram.amanoteam.com/docs/start/auth"
+                    "More info: https://docs.hydrogram.org/en/latest/start/auth.html"
                 )
 
             await self.storage.api_id(self.api_id)
@@ -854,32 +851,46 @@ class Client(Methods):
 
         None if in_memory else Path(directory).mkdir(parents=True, exist_ok=True)
         file_path = Path(directory).resolve() / file_name
-        temp_file_path = file_path.with_suffix(".temp")
-        with BytesIO() if in_memory else Path(temp_file_path).open("wb") as file:
-            try:
-                async for chunk in self.get_file(
-                    file_id, file_size, 0, 0, progress, progress_args
-                ):
-                    file.write(chunk)
-            except BaseException as e:
-                if not in_memory:
-                    file.close()
-                    Path(temp_file_path).unlink()
 
-                if isinstance(e, asyncio.CancelledError):
-                    raise e
+        random_suffix = "".join(random.choices(string.ascii_letters + string.digits, k=8))
+        temp_file_path = file_path.with_name(file_path.stem + "_" + random_suffix + ".temp")
 
-                if isinstance(e, hydrogram.errors.FloodWait):
-                    raise e
+        file = BytesIO() if in_memory else Path(temp_file_path).open("wb")  # noqa: SIM115 file is closed manually
 
-                return None
-            else:
-                if in_memory:
-                    file.name = file_name
-                    return file
+        try:
+            async for chunk in self.get_file(file_id, file_size, 0, 0, progress, progress_args):
+                file.write(chunk)
+        except BaseException as e:
+            if not in_memory:
                 file.close()
-                shutil.move(temp_file_path, file_path)
-                return file_path
+                Path(temp_file_path).unlink()
+
+            if isinstance(e, asyncio.CancelledError):
+                raise e
+
+            if isinstance(e, hydrogram.errors.FloodWait):
+                raise e
+
+            return None
+        else:
+            if in_memory:
+                file.name = file_name
+                return file
+
+            file.close()
+
+            async with self.file_lock:
+                final_file_path: Path = file_path
+                counter = 1
+                while final_file_path.exists():
+                    final_file_path = file_path.with_name(
+                        f"{file_path.stem}({counter}){file_path.suffix}"
+                    )
+                    counter += 1
+
+                shutil.move(temp_file_path, final_file_path)
+
+            return final_file_path
 
     async def get_file(
         self,
@@ -887,26 +898,23 @@ class Client(Methods):
         file_size: int = 0,
         limit: int = 0,
         offset: int = 0,
-        progress: Optional[Callable] = None,
+        progress: Callable | None = None,
         progress_args: tuple = (),
-    ) -> Optional[AsyncGenerator[bytes, None]]:
+    ) -> AsyncGenerator[bytes, None]:
         async with self.get_file_semaphore:
             file_type = file_id.file_type
-
             if file_type == FileType.CHAT_PHOTO:
                 if file_id.chat_id > 0:
                     peer = raw.types.InputPeerUser(
                         user_id=file_id.chat_id, access_hash=file_id.chat_access_hash
                     )
+                elif file_id.chat_access_hash == 0:
+                    peer = raw.types.InputPeerChat(chat_id=-file_id.chat_id)
                 else:
-                    if file_id.chat_access_hash == 0:
-                        peer = raw.types.InputPeerChat(chat_id=-file_id.chat_id)
-                    else:
-                        peer = raw.types.InputPeerChannel(
-                            channel_id=utils.get_channel_id(file_id.chat_id),
-                            access_hash=file_id.chat_access_hash,
-                        )
-
+                    peer = raw.types.InputPeerChannel(
+                        channel_id=utils.get_channel_id(file_id.chat_id),
+                        access_hash=file_id.chat_access_hash,
+                    )
                 location = raw.types.InputPeerPhotoFileLocation(
                     peer=peer,
                     photo_id=file_id.media_id,
@@ -931,44 +939,48 @@ class Client(Methods):
             total = abs(limit) or (1 << 31) - 1
             chunk_size = 1024 * 1024
             offset_bytes = abs(offset) * chunk_size
-
             dc_id = file_id.dc_id
 
-            session = Session(
-                self,
-                dc_id,
-                await Auth(self, dc_id, await self.storage.test_mode()).create()
-                if dc_id != await self.storage.dc_id()
-                else await self.storage.auth_key(),
-                await self.storage.test_mode(),
-                is_media=True,
-            )
-
             try:
-                await session.start()
+                session = self.media_sessions.get(dc_id)
+                if not session:
+                    auth_key = (
+                        await Auth(self, dc_id, await self.storage.test_mode()).create()
+                        if dc_id != await self.storage.dc_id()
+                        else await self.storage.auth_key()
+                    )
+                    session = self.media_sessions[dc_id] = Session(
+                        self, dc_id, auth_key, await self.storage.test_mode(), is_media=True
+                    )
+                    await session.start()
 
-                if dc_id != await self.storage.dc_id():
-                    exported_auth = await self.invoke(
-                        raw.functions.auth.ExportAuthorization(dc_id=dc_id)
+                    if dc_id != await self.storage.dc_id():
+                        for _ in range(3):
+                            exported_auth = await self.invoke(
+                                raw.functions.auth.ExportAuthorization(dc_id=dc_id)
+                            )
+                            try:
+                                await session.invoke(
+                                    raw.functions.auth.ImportAuthorization(
+                                        id=exported_auth.id, bytes=exported_auth.bytes
+                                    )
+                                )
+                                break
+                            except AuthBytesInvalid:
+                                continue
+                        else:
+                            raise AuthBytesInvalid
+
+                while True:
+                    r = await session.invoke(
+                        raw.functions.upload.GetFile(
+                            location=location, offset=offset_bytes, limit=chunk_size
+                        ),
+                        sleep_threshold=30,
                     )
 
-                    await session.invoke(
-                        raw.functions.auth.ImportAuthorization(
-                            id=exported_auth.id, bytes=exported_auth.bytes
-                        )
-                    )
-
-                r = await session.invoke(
-                    raw.functions.upload.GetFile(
-                        location=location, offset=offset_bytes, limit=chunk_size
-                    ),
-                    sleep_threshold=30,
-                )
-
-                if isinstance(r, raw.types.upload.File):
-                    while True:
+                    if isinstance(r, raw.types.upload.File):
                         chunk = r.bytes
-
                         yield chunk
 
                         current += 1
@@ -990,112 +1002,102 @@ class Client(Methods):
                         if len(chunk) < chunk_size or current >= total:
                             break
 
-                        r = await session.invoke(
-                            raw.functions.upload.GetFile(
-                                location=location, offset=offset_bytes, limit=chunk_size
-                            ),
-                            sleep_threshold=30,
+                    elif isinstance(r, raw.types.upload.FileCdnRedirect):
+                        cdn_session = Session(
+                            self,
+                            r.dc_id,
+                            await Auth(self, r.dc_id, await self.storage.test_mode()).create(),
+                            await self.storage.test_mode(),
+                            is_media=True,
+                            is_cdn=True,
                         )
 
-                elif isinstance(r, raw.types.upload.FileCdnRedirect):
-                    cdn_session = Session(
-                        self,
-                        r.dc_id,
-                        await Auth(self, r.dc_id, await self.storage.test_mode()).create(),
-                        await self.storage.test_mode(),
-                        is_media=True,
-                        is_cdn=True,
-                    )
+                        try:
+                            await cdn_session.start()
 
-                    try:
-                        await cdn_session.start()
-
-                        while True:
-                            r2 = await cdn_session.invoke(
-                                raw.functions.upload.GetCdnFile(
-                                    file_token=r.file_token,
-                                    offset=offset_bytes,
-                                    limit=chunk_size,
-                                )
-                            )
-
-                            if isinstance(r2, raw.types.upload.CdnFileReuploadNeeded):
-                                try:
-                                    await session.invoke(
-                                        raw.functions.upload.ReuploadCdnFile(
-                                            file_token=r.file_token,
-                                            request_token=r2.request_token,
-                                        )
+                            while True:
+                                r2 = await cdn_session.invoke(
+                                    raw.functions.upload.GetCdnFile(
+                                        file_token=r.file_token,
+                                        offset=offset_bytes,
+                                        limit=chunk_size,
                                     )
-                                except VolumeLocNotFound:
+                                )
+
+                                if isinstance(r2, raw.types.upload.CdnFileReuploadNeeded):
+                                    try:
+                                        await session.invoke(
+                                            raw.functions.upload.ReuploadCdnFile(
+                                                file_token=r.file_token,
+                                                request_token=r2.request_token,
+                                            )
+                                        )
+                                    except VolumeLocNotFound:
+                                        break
+                                    else:
+                                        continue
+
+                                chunk = r2.bytes
+
+                                # https://core.telegram.org/cdn#decrypting-files
+                                decrypted_chunk = aes.ctr256_decrypt(
+                                    chunk,
+                                    r.encryption_key,
+                                    bytearray(
+                                        r.encryption_iv[:-4]
+                                        + (offset_bytes // 16).to_bytes(4, "big")
+                                    ),
+                                )
+
+                                hashes = await session.invoke(
+                                    raw.functions.upload.GetCdnFileHashes(
+                                        file_token=r.file_token, offset=offset_bytes
+                                    )
+                                )
+
+                                # https://core.telegram.org/cdn#verifying-files
+                                for i, h in enumerate(hashes):
+                                    cdn_chunk = decrypted_chunk[h.limit * i : h.limit * (i + 1)]
+                                    CDNFileHashMismatch.check(
+                                        h.hash == sha256(cdn_chunk).digest(),
+                                        "h.hash == sha256(cdn_chunk).digest()",
+                                    )
+
+                                yield decrypted_chunk
+
+                                current += 1
+                                offset_bytes += chunk_size
+
+                                if progress:
+                                    func = functools.partial(
+                                        progress,
+                                        min(offset_bytes, file_size)
+                                        if file_size != 0
+                                        else offset_bytes,
+                                        file_size,
+                                        *progress_args,
+                                    )
+
+                                    if inspect.iscoroutinefunction(progress):
+                                        await func()
+                                    else:
+                                        await self.loop.run_in_executor(self.executor, func)
+
+                                if len(chunk) < chunk_size or current >= total:
                                     break
-                                else:
-                                    continue
-
-                            chunk = r2.bytes
-
-                            # https://core.telegram.org/cdn#decrypting-files
-                            decrypted_chunk = aes.ctr256_decrypt(
-                                chunk,
-                                r.encryption_key,
-                                bytearray(
-                                    r.encryption_iv[:-4] + (offset_bytes // 16).to_bytes(4, "big")
-                                ),
-                            )
-
-                            hashes = await session.invoke(
-                                raw.functions.upload.GetCdnFileHashes(
-                                    file_token=r.file_token, offset=offset_bytes
-                                )
-                            )
-
-                            # https://core.telegram.org/cdn#verifying-files
-                            for i, h in enumerate(hashes):
-                                cdn_chunk = decrypted_chunk[h.limit * i : h.limit * (i + 1)]
-                                CDNFileHashMismatch.check(
-                                    h.hash == sha256(cdn_chunk).digest(),
-                                    "h.hash == sha256(cdn_chunk).digest()",
-                                )
-
-                            yield decrypted_chunk
-
-                            current += 1
-                            offset_bytes += chunk_size
-
-                            if progress:
-                                func = functools.partial(
-                                    progress,
-                                    min(offset_bytes, file_size)
-                                    if file_size != 0
-                                    else offset_bytes,
-                                    file_size,
-                                    *progress_args,
-                                )
-
-                                if inspect.iscoroutinefunction(progress):
-                                    await func()
-                                else:
-                                    await self.loop.run_in_executor(self.executor, func)
-
-                            if len(chunk) < chunk_size or current >= total:
-                                break
-                    except Exception as e:
-                        raise e
-                    finally:
-                        await cdn_session.stop()
+                        finally:
+                            await cdn_session.stop()
             except hydrogram.StopTransmission:
                 raise
             except hydrogram.errors.FloodWait:
                 raise
             except Exception as e:
                 log.exception(e)
-            finally:
-                await session.stop()
 
-    def guess_mime_type(self, filename: str) -> Optional[str]:
+    def guess_mime_type(self, filename: str) -> str | None:
         return self.mimetypes.guess_type(filename)[0]
 
-    def guess_extension(self, mime_type: str) -> Optional[str]:
+    def guess_extension(self, mime_type: str) -> str | None:
         return self.mimetypes.guess_extension(mime_type)
 
 
