@@ -1,6 +1,6 @@
 #  Hydrogram - Telegram MTProto API Client Library for Python
 #  Copyright (C) 2017-2023 Dan <https://github.com/delivrance>
-#  Copyright (C) 2023-present Amano LLC <https://amanoteam.com>
+#  Copyright (C) 2023-present Hydrogram <https://hydrogram.org>
 #
 #  This file is part of Hydrogram.
 #
@@ -17,7 +17,9 @@
 #  You should have received a copy of the GNU Lesser General Public License
 #  along with Hydrogram.  If not, see <http://www.gnu.org/licenses/>.
 
-from typing import ClassVar, Optional
+from __future__ import annotations
+
+from typing import ClassVar
 
 from .exceptions import (
     AboutTooLong,
@@ -493,6 +495,7 @@ from .exceptions import (
     service_unavailable_503,
     unauthorized_401,
 )
+from .pyromod import ListenerStopped, ListenerTimeout
 from .rpc_error import UnknownError
 
 
@@ -530,14 +533,14 @@ class SecurityError(Exception):
 class SecurityCheckMismatch(SecurityError):  # noqa: N818
     """Raised when a security check mismatch occurs."""
 
-    def __init__(self, msg: Optional[str] = None):
+    def __init__(self, msg: str | None = None):
         super().__init__("A security check mismatch has occurred." if msg is None else msg)
 
 
 class CDNFileHashMismatch(SecurityError):  # noqa: N818
     """Raised when a CDN file hash mismatch occurs."""
 
-    def __init__(self, msg: Optional[str] = None):
+    def __init__(self, msg: str | None = None):
         super().__init__("A CDN file hash mismatch has occurred." if msg is None else msg)
 
 
@@ -746,6 +749,8 @@ __all__ = [
     "LastnameInvalid",
     "LimitInvalid",
     "LinkNotModified",
+    "ListenerStopped",
+    "ListenerTimeout",
     "LocationInvalid",
     "MaxIdInvalid",
     "MaxQtsInvalid",
