@@ -1,6 +1,6 @@
 #  Hydrogram - Telegram MTProto API Client Library for Python
 #  Copyright (C) 2017-2023 Dan <https://github.com/delivrance>
-#  Copyright (C) 2023-present Amano LLC <https://amanoteam.com>
+#  Copyright (C) 2023-present Hydrogram <https://hydrogram.org>
 #
 #  This file is part of Hydrogram.
 #
@@ -17,9 +17,12 @@
 #  You should have received a copy of the GNU Lesser General Public License
 #  along with Hydrogram.  If not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import annotations
+
 import inspect
 import re
-from typing import Callable, List, Optional, Pattern, Union
+from re import Pattern
+from typing import Callable
 
 import hydrogram
 from hydrogram import enums
@@ -34,7 +37,7 @@ from hydrogram.types import (
 
 
 class Filter:
-    async def __call__(self, client: "hydrogram.Client", update: Update):
+    async def __call__(self, client: hydrogram.Client, update: Update):
         raise NotImplementedError
 
     def __invert__(self):
@@ -51,7 +54,7 @@ class InvertFilter(Filter):
     def __init__(self, base):
         self.base = base
 
-    async def __call__(self, client: "hydrogram.Client", update: Update):
+    async def __call__(self, client: hydrogram.Client, update: Update):
         if inspect.iscoroutinefunction(self.base.__call__):
             x = await self.base(client, update)
         else:
@@ -65,7 +68,7 @@ class AndFilter(Filter):
         self.base = base
         self.other = other
 
-    async def __call__(self, client: "hydrogram.Client", update: Update):
+    async def __call__(self, client: hydrogram.Client, update: Update):
         if inspect.iscoroutinefunction(self.base.__call__):
             x = await self.base(client, update)
         else:
@@ -88,7 +91,7 @@ class OrFilter(Filter):
         self.base = base
         self.other = other
 
-    async def __call__(self, client: "hydrogram.Client", update: Update):
+    async def __call__(self, client: hydrogram.Client, update: Update):
         if inspect.iscoroutinefunction(self.base.__call__):
             x = await self.base(client, update)
         else:
@@ -109,7 +112,7 @@ class OrFilter(Filter):
 CUSTOM_FILTER_NAME = "CustomFilter"
 
 
-def create(func: Callable, name: Optional[str] = None, **kwargs) -> Filter:
+def create(func: Callable, name: str | None = None, **kwargs) -> Filter:
     """Easily create a custom filter.
 
     Custom filters give you extra control over which updates are allowed or not to be processed by your handlers.
@@ -140,7 +143,7 @@ def create(func: Callable, name: Optional[str] = None, **kwargs) -> Filter:
 
 
 # region all_filter
-async def all_filter(_, __, ___):
+def all_filter(_, __, ___):
     return True
 
 
@@ -152,7 +155,7 @@ all = create(all_filter)
 
 
 # region me_filter
-async def me_filter(_, __, m: Message):
+def me_filter(_, __, m: Message):
     return bool(m.from_user.is_self if m.from_user else getattr(m, "outgoing", False))
 
 
@@ -164,7 +167,7 @@ me = create(me_filter)
 
 
 # region bot_filter
-async def bot_filter(_, __, m: Message):
+def bot_filter(_, __, m: Message):
     return bool(m.from_user and m.from_user.is_bot)
 
 
@@ -176,7 +179,7 @@ bot = create(bot_filter)
 
 
 # region incoming_filter
-async def incoming_filter(_, __, m: Message):
+def incoming_filter(_, __, m: Message):
     return not m.outgoing
 
 
@@ -188,7 +191,7 @@ incoming = create(incoming_filter)
 
 
 # region outgoing_filter
-async def outgoing_filter(_, __, m: Message):
+def outgoing_filter(_, __, m: Message):
     return m.outgoing
 
 
@@ -200,7 +203,7 @@ outgoing = create(outgoing_filter)
 
 
 # region text_filter
-async def text_filter(_, __, m: Message):
+def text_filter(_, __, m: Message):
     return bool(m.text)
 
 
@@ -212,7 +215,7 @@ text = create(text_filter)
 
 
 # region reply_filter
-async def reply_filter(_, __, m: Message):
+def reply_filter(_, __, m: Message):
     return bool(m.reply_to_message_id)
 
 
@@ -224,7 +227,7 @@ reply = create(reply_filter)
 
 
 # region forwarded_filter
-async def forwarded_filter(_, __, m: Message):
+def forwarded_filter(_, __, m: Message):
     return bool(m.forward_date)
 
 
@@ -236,7 +239,7 @@ forwarded = create(forwarded_filter)
 
 
 # region caption_filter
-async def caption_filter(_, __, m: Message):
+def caption_filter(_, __, m: Message):
     return bool(m.caption)
 
 
@@ -248,7 +251,7 @@ caption = create(caption_filter)
 
 
 # region audio_filter
-async def audio_filter(_, __, m: Message):
+def audio_filter(_, __, m: Message):
     return bool(m.audio)
 
 
@@ -260,7 +263,7 @@ audio = create(audio_filter)
 
 
 # region document_filter
-async def document_filter(_, __, m: Message):
+def document_filter(_, __, m: Message):
     return bool(m.document)
 
 
@@ -272,7 +275,7 @@ document = create(document_filter)
 
 
 # region photo_filter
-async def photo_filter(_, __, m: Message):
+def photo_filter(_, __, m: Message):
     return bool(m.photo)
 
 
@@ -284,7 +287,7 @@ photo = create(photo_filter)
 
 
 # region sticker_filter
-async def sticker_filter(_, __, m: Message):
+def sticker_filter(_, __, m: Message):
     return bool(m.sticker)
 
 
@@ -296,7 +299,7 @@ sticker = create(sticker_filter)
 
 
 # region animation_filter
-async def animation_filter(_, __, m: Message):
+def animation_filter(_, __, m: Message):
     return bool(m.animation)
 
 
@@ -308,7 +311,7 @@ animation = create(animation_filter)
 
 
 # region game_filter
-async def game_filter(_, __, m: Message):
+def game_filter(_, __, m: Message):
     return bool(m.game)
 
 
@@ -320,7 +323,7 @@ game = create(game_filter)
 
 
 # region video_filter
-async def video_filter(_, __, m: Message):
+def video_filter(_, __, m: Message):
     return bool(m.video)
 
 
@@ -332,7 +335,7 @@ video = create(video_filter)
 
 
 # region media_group_filter
-async def media_group_filter(_, __, m: Message):
+def media_group_filter(_, __, m: Message):
     return bool(m.media_group_id)
 
 
@@ -344,7 +347,7 @@ media_group = create(media_group_filter)
 
 
 # region voice_filter
-async def voice_filter(_, __, m: Message):
+def voice_filter(_, __, m: Message):
     return bool(m.voice)
 
 
@@ -356,7 +359,7 @@ voice = create(voice_filter)
 
 
 # region video_note_filter
-async def video_note_filter(_, __, m: Message):
+def video_note_filter(_, __, m: Message):
     return bool(m.video_note)
 
 
@@ -368,7 +371,7 @@ video_note = create(video_note_filter)
 
 
 # region contact_filter
-async def contact_filter(_, __, m: Message):
+def contact_filter(_, __, m: Message):
     return bool(m.contact)
 
 
@@ -380,7 +383,7 @@ contact = create(contact_filter)
 
 
 # region location_filter
-async def location_filter(_, __, m: Message):
+def location_filter(_, __, m: Message):
     return bool(m.location)
 
 
@@ -392,7 +395,7 @@ location = create(location_filter)
 
 
 # region venue_filter
-async def venue_filter(_, __, m: Message):
+def venue_filter(_, __, m: Message):
     return bool(m.venue)
 
 
@@ -404,7 +407,7 @@ venue = create(venue_filter)
 
 
 # region web_page_filter
-async def web_page_filter(_, __, m: Message):
+def web_page_filter(_, __, m: Message):
     return bool(m.web_page)
 
 
@@ -416,7 +419,7 @@ web_page = create(web_page_filter)
 
 
 # region poll_filter
-async def poll_filter(_, __, m: Message):
+def poll_filter(_, __, m: Message):
     return bool(m.poll)
 
 
@@ -428,7 +431,7 @@ poll = create(poll_filter)
 
 
 # region dice_filter
-async def dice_filter(_, __, m: Message):
+def dice_filter(_, __, m: Message):
     return bool(m.dice)
 
 
@@ -440,7 +443,7 @@ dice = create(dice_filter)
 
 
 # region media_spoiler
-async def media_spoiler_filter(_, __, m: Message):
+def media_spoiler_filter(_, __, m: Message):
     return bool(m.has_media_spoiler)
 
 
@@ -452,8 +455,14 @@ media_spoiler = create(media_spoiler_filter)
 
 
 # region private_filter
-async def private_filter(_, __, m: Message):
-    return bool(m.chat and m.chat.type in {enums.ChatType.PRIVATE, enums.ChatType.BOT})
+def private_filter(_, __, m: CallbackQuery | Message):
+    if isinstance(m, Message):
+        value = m.chat
+    elif isinstance(m, CallbackQuery):
+        value = m.message.chat
+    else:
+        raise ValueError(f"Private filter doesn't work with {type(m)}")
+    return bool(value and value.type in {enums.ChatType.PRIVATE, enums.ChatType.BOT})
 
 
 private = create(private_filter)
@@ -464,8 +473,14 @@ private = create(private_filter)
 
 
 # region group_filter
-async def group_filter(_, __, m: Message):
-    return bool(m.chat and m.chat.type in {enums.ChatType.GROUP, enums.ChatType.SUPERGROUP})
+def group_filter(_, __, m: CallbackQuery | Message):
+    if isinstance(m, Message):
+        value = m.chat
+    elif isinstance(m, CallbackQuery):
+        value = m.message.chat
+    else:
+        raise ValueError(f"Group filter doesn't work with {type(m)}")
+    return bool(value and value.type in {enums.ChatType.GROUP, enums.ChatType.SUPERGROUP})
 
 
 group = create(group_filter)
@@ -476,8 +491,14 @@ group = create(group_filter)
 
 
 # region channel_filter
-async def channel_filter(_, __, m: Message):
-    return bool(m.chat and m.chat.type == enums.ChatType.CHANNEL)
+def channel_filter(_, __, m: CallbackQuery | Message):
+    if isinstance(m, Message):
+        value = m.chat
+    elif isinstance(m, CallbackQuery):
+        value = m.message.chat
+    else:
+        raise ValueError(f"Channel filter doesn't work with {type(m)}")
+    return bool(value and value.type == enums.ChatType.CHANNEL)
 
 
 channel = create(channel_filter)
@@ -488,7 +509,7 @@ channel = create(channel_filter)
 
 
 # region new_chat_members_filter
-async def new_chat_members_filter(_, __, m: Message):
+def new_chat_members_filter(_, __, m: Message):
     return bool(m.new_chat_members)
 
 
@@ -500,7 +521,7 @@ new_chat_members = create(new_chat_members_filter)
 
 
 # region left_chat_member_filter
-async def left_chat_member_filter(_, __, m: Message):
+def left_chat_member_filter(_, __, m: Message):
     return bool(m.left_chat_member)
 
 
@@ -512,7 +533,7 @@ left_chat_member = create(left_chat_member_filter)
 
 
 # region new_chat_title_filter
-async def new_chat_title_filter(_, __, m: Message):
+def new_chat_title_filter(_, __, m: Message):
     return bool(m.new_chat_title)
 
 
@@ -524,7 +545,7 @@ new_chat_title = create(new_chat_title_filter)
 
 
 # region new_chat_photo_filter
-async def new_chat_photo_filter(_, __, m: Message):
+def new_chat_photo_filter(_, __, m: Message):
     return bool(m.new_chat_photo)
 
 
@@ -536,7 +557,7 @@ new_chat_photo = create(new_chat_photo_filter)
 
 
 # region delete_chat_photo_filter
-async def delete_chat_photo_filter(_, __, m: Message):
+def delete_chat_photo_filter(_, __, m: Message):
     return bool(m.delete_chat_photo)
 
 
@@ -548,7 +569,7 @@ delete_chat_photo = create(delete_chat_photo_filter)
 
 
 # region group_chat_created_filter
-async def group_chat_created_filter(_, __, m: Message):
+def group_chat_created_filter(_, __, m: Message):
     return bool(m.group_chat_created)
 
 
@@ -560,7 +581,7 @@ group_chat_created = create(group_chat_created_filter)
 
 
 # region supergroup_chat_created_filter
-async def supergroup_chat_created_filter(_, __, m: Message):
+def supergroup_chat_created_filter(_, __, m: Message):
     return bool(m.supergroup_chat_created)
 
 
@@ -572,7 +593,7 @@ supergroup_chat_created = create(supergroup_chat_created_filter)
 
 
 # region channel_chat_created_filter
-async def channel_chat_created_filter(_, __, m: Message):
+def channel_chat_created_filter(_, __, m: Message):
     return bool(m.channel_chat_created)
 
 
@@ -584,7 +605,7 @@ channel_chat_created = create(channel_chat_created_filter)
 
 
 # region migrate_to_chat_id_filter
-async def migrate_to_chat_id_filter(_, __, m: Message):
+def migrate_to_chat_id_filter(_, __, m: Message):
     return bool(m.migrate_to_chat_id)
 
 
@@ -596,7 +617,7 @@ migrate_to_chat_id = create(migrate_to_chat_id_filter)
 
 
 # region migrate_from_chat_id_filter
-async def migrate_from_chat_id_filter(_, __, m: Message):
+def migrate_from_chat_id_filter(_, __, m: Message):
     return bool(m.migrate_from_chat_id)
 
 
@@ -608,7 +629,7 @@ migrate_from_chat_id = create(migrate_from_chat_id_filter)
 
 
 # region pinned_message_filter
-async def pinned_message_filter(_, __, m: Message):
+def pinned_message_filter(_, __, m: Message):
     return bool(m.pinned_message)
 
 
@@ -620,7 +641,7 @@ pinned_message = create(pinned_message_filter)
 
 
 # region game_high_score_filter
-async def game_high_score_filter(_, __, m: Message):
+def game_high_score_filter(_, __, m: Message):
     return bool(m.game_high_score)
 
 
@@ -632,7 +653,7 @@ game_high_score = create(game_high_score_filter)
 
 
 # region reply_keyboard_filter
-async def reply_keyboard_filter(_, __, m: Message):
+def reply_keyboard_filter(_, __, m: Message):
     return isinstance(m.reply_markup, ReplyKeyboardMarkup)
 
 
@@ -644,7 +665,7 @@ reply_keyboard = create(reply_keyboard_filter)
 
 
 # region inline_keyboard_filter
-async def inline_keyboard_filter(_, __, m: Message):
+def inline_keyboard_filter(_, __, m: Message):
     return isinstance(m.reply_markup, InlineKeyboardMarkup)
 
 
@@ -656,7 +677,7 @@ inline_keyboard = create(inline_keyboard_filter)
 
 
 # region mentioned_filter
-async def mentioned_filter(_, __, m: Message):
+def mentioned_filter(_, __, m: Message):
     return bool(m.mentioned)
 
 
@@ -668,7 +689,7 @@ mentioned = create(mentioned_filter)
 
 
 # region via_bot_filter
-async def via_bot_filter(_, __, m: Message):
+def via_bot_filter(_, __, m: Message):
     return bool(m.via_bot)
 
 
@@ -680,7 +701,7 @@ via_bot = create(via_bot_filter)
 
 
 # region video_chat_started_filter
-async def video_chat_started_filter(_, __, m: Message):
+def video_chat_started_filter(_, __, m: Message):
     return bool(m.video_chat_started)
 
 
@@ -692,7 +713,7 @@ video_chat_started = create(video_chat_started_filter)
 
 
 # region video_chat_ended_filter
-async def video_chat_ended_filter(_, __, m: Message):
+def video_chat_ended_filter(_, __, m: Message):
     return bool(m.video_chat_ended)
 
 
@@ -704,7 +725,7 @@ video_chat_ended = create(video_chat_ended_filter)
 
 
 # region video_chat_members_invited_filter
-async def video_chat_members_invited_filter(_, __, m: Message):
+def video_chat_members_invited_filter(_, __, m: Message):
     return bool(m.video_chat_members_invited)
 
 
@@ -716,7 +737,7 @@ video_chat_members_invited = create(video_chat_members_invited_filter)
 
 
 # region service_filter
-async def service_filter(_, __, m: Message):
+def service_filter(_, __, m: Message):
     return bool(m.service)
 
 
@@ -734,7 +755,7 @@ A service message contains any of the following fields set: *left_chat_member*,
 
 
 # region media_filter
-async def media_filter(_, __, m: Message):
+def media_filter(_, __, m: Message):
     return bool(m.media)
 
 
@@ -750,7 +771,7 @@ A media message contains any of the following fields set: *audio*, *document*, *
 
 
 # region scheduled_filter
-async def scheduled_filter(_, __, m: Message):
+def scheduled_filter(_, __, m: Message):
     return bool(m.scheduled)
 
 
@@ -762,7 +783,7 @@ scheduled = create(scheduled_filter)
 
 
 # region from_scheduled_filter
-async def from_scheduled_filter(_, __, m: Message):
+def from_scheduled_filter(_, __, m: Message):
     return bool(m.from_scheduled)
 
 
@@ -774,7 +795,7 @@ from_scheduled = create(from_scheduled_filter)
 
 
 # region linked_channel_filter
-async def linked_channel_filter(_, __, m: Message):
+def linked_channel_filter(_, __, m: Message):
     return bool(m.forward_from_chat and not m.from_user)
 
 
@@ -787,8 +808,8 @@ linked_channel = create(linked_channel_filter)
 
 # region command_filter
 def command(
-    commands: Union[str, List[str]],
-    prefixes: Union[str, List[str]] = "/",
+    commands: str | list[str],
+    prefixes: str | list[str] = "/",
     case_sensitive: bool = False,
 ):
     """Filter commands, i.e.: text messages starting with "/" or any other custom prefix.
@@ -811,7 +832,7 @@ def command(
     """
     command_re = re.compile(r"([\"'])(.*?)(?<!\\)\1|(\S+)")
 
-    async def func(flt, client: hydrogram.Client, message: Message):
+    def func(flt, client: hydrogram.Client, message: Message):
         username = client.me.username or ""
         text = message.text or message.caption
         message.command = None
@@ -873,7 +894,7 @@ def command(
 # endregion
 
 
-def regex(pattern: Union[str, Pattern], flags: int = 0):
+def regex(pattern: str | Pattern, flags: int = 0):
     """Filter updates that match a given regular expression pattern.
 
     Can be applied to handlers that receive one of the following updates:
@@ -893,7 +914,7 @@ def regex(pattern: Union[str, Pattern], flags: int = 0):
             Regex flags.
     """
 
-    async def func(flt, _, update: Update):
+    def func(flt, _, update: Update):
         if isinstance(update, Message):
             value = update.text or update.caption
         elif isinstance(update, CallbackQuery):
@@ -928,7 +949,7 @@ class user(Filter, set):  # noqa: N801
             Defaults to None (no users).
     """
 
-    def __init__(self, users: Optional[Union[int, str, List[Union[int, str]]]] = None):
+    def __init__(self, users: int | str | list[int | str] | None = None):
         users = [] if users is None else users if isinstance(users, list) else [users]
 
         super().__init__(
@@ -957,7 +978,7 @@ class chat(Filter, set):  # noqa: N801
             Defaults to None (no chats).
     """
 
-    def __init__(self, chats: Optional[Union[int, str, List[Union[int, str]]]] = None):
+    def __init__(self, chats: int | str | list[int | str] | None = None):
         chats = [] if chats is None else chats if isinstance(chats, list) else [chats]
 
         super().__init__(
