@@ -1,6 +1,6 @@
 #  Hydrogram - Telegram MTProto API Client Library for Python
 #  Copyright (C) 2017-2023 Dan <https://github.com/delivrance>
-#  Copyright (C) 2023-present Amano LLC <https://amanoteam.com>
+#  Copyright (C) 2023-present Hydrogram <https://hydrogram.org>
 #
 #  This file is part of Hydrogram.
 #
@@ -26,6 +26,7 @@ from .decorators import Decorators
 from .invite_links import InviteLinks
 from .messages import Messages
 from .password import Password
+from .pyromod import Pyromod
 from .users import Users
 from .utilities import Utilities
 
@@ -39,6 +40,7 @@ class Methods(
     Chats,
     Users,
     Messages,
+    Pyromod,
     Decorators,
     Utilities,
     InviteLinks,
