@@ -1,6 +1,6 @@
 #  Hydrogram - Telegram MTProto API Client Library for Python
 #  Copyright (C) 2017-2023 Dan <https://github.com/delivrance>
-#  Copyright (C) 2023-present Amano LLC <https://amanoteam.com>
+#  Copyright (C) 2023-present Hydrogram <https://hydrogram.org>
 #
 #  This file is part of Hydrogram.
 #
@@ -19,6 +19,7 @@
 
 from .add_handler import AddHandler
 from .export_session_string import ExportSessionString
+from .remove_error_handler import RemoveErrorHandler
 from .remove_handler import RemoveHandler
 from .restart import Restart
 from .run import Run
@@ -31,6 +32,7 @@ class Utilities(
     AddHandler,
     ExportSessionString,
     RemoveHandler,
+    RemoveErrorHandler,
     Restart,
     Run,
     Start,
