@@ -1,6 +1,6 @@
 #  Hydrogram - Telegram MTProto API Client Library for Python
 #  Copyright (C) 2017-2023 Dan <https://github.com/delivrance>
-#  Copyright (C) 2023-present Amano LLC <https://amanoteam.com>
+#  Copyright (C) 2023-present Hydrogram <https://hydrogram.org>
 #
 #  This file is part of Hydrogram.
 #
@@ -27,4 +27,4 @@ for k, v in objects.items():
     objects[k] = getattr(import_module(path), name)
 
 
-__all__ = ["types", "functions", "base", "core", "objects"]
+__all__ = ["base", "core", "functions", "objects", "types"]
