@@ -1,6 +1,6 @@
 #  Hydrogram - Telegram MTProto API Client Library for Python
 #  Copyright (C) 2017-2023 Dan <https://github.com/delivrance>
-#  Copyright (C) 2023-present Amano LLC <https://amanoteam.com>
+#  Copyright (C) 2023-present Hydrogram <https://hydrogram.org>
 #
 #  This file is part of Hydrogram.
 #
@@ -18,11 +18,10 @@
 #  along with Hydrogram.  If not, see <http://www.gnu.org/licenses/>.
 
 from typing import Any
-from typing import List as TList
 
 from .tl_object import TLObject
 
 
-class List(TList[Any], TLObject):
+class List(list[Any], TLObject):
     def __repr__(self) -> str:
         return f"hydrogram.raw.core.List([{','.join(TLObject.__repr__(i) for i in self)}])"
