@@ -1,6 +1,6 @@
 #  Hydrogram - Telegram MTProto API Client Library for Python
 #  Copyright (C) 2017-2023 Dan <https://github.com/delivrance>
-#  Copyright (C) 2023-present Amano LLC <https://amanoteam.com>
+#  Copyright (C) 2023-present Hydrogram <https://hydrogram.org>
 #
 #  This file is part of Hydrogram.
 #
@@ -20,4 +20,4 @@
 from .sent_code import SentCode
 from .terms_of_service import TermsOfService
 
-__all__ = ["TermsOfService", "SentCode"]
+__all__ = ["SentCode", "TermsOfService"]
