@@ -1,6 +1,6 @@
 #  Hydrogram - Telegram MTProto API Client Library for Python
 #  Copyright (C) 2017-2023 Dan <https://github.com/delivrance>
-#  Copyright (C) 2023-present Amano LLC <https://amanoteam.com>
+#  Copyright (C) 2023-present Hydrogram <https://hydrogram.org>
 #
 #  This file is part of Hydrogram.
 #
@@ -29,5 +29,6 @@ class MenuButtonCommands(MenuButton):
     def __init__(self):
         super().__init__("commands")
 
-    async def write(self, client: "hydrogram.Client") -> "raw.types.BotMenuButtonCommands":
+    @staticmethod
+    async def write(client: "hydrogram.Client") -> "raw.types.BotMenuButtonCommands":
         return raw.types.BotMenuButtonCommands()
