@@ -1,6 +1,6 @@
 #  Hydrogram - Telegram MTProto API Client Library for Python
 #  Copyright (C) 2017-2023 Dan <https://github.com/delivrance>
-#  Copyright (C) 2023-present Amano LLC <https://amanoteam.com>
+#  Copyright (C) 2023-present Hydrogram <https://hydrogram.org>
 #
 #  This file is part of Hydrogram.
 #
@@ -21,8 +21,10 @@ import hydrogram
 
 
 class Update:
-    def stop_propagation(self):
+    @staticmethod
+    def stop_propagation():
         raise hydrogram.StopPropagation
 
-    def continue_propagation(self):
+    @staticmethod
+    def continue_propagation():
         raise hydrogram.ContinuePropagation
