@@ -1,6 +1,6 @@
 #  Hydrogram - Telegram MTProto API Client Library for Python
 #  Copyright (C) 2017-2023 Dan <https://github.com/delivrance>
-#  Copyright (C) 2023-present Amano LLC <https://amanoteam.com>
+#  Copyright (C) 2023-present Hydrogram <https://hydrogram.org>
 #
 #  This file is part of Hydrogram.
 #
@@ -17,13 +17,19 @@
 #  You should have received a copy of the GNU Lesser General Public License
 #  along with Hydrogram.  If not, see <http://www.gnu.org/licenses/>.
 
-from datetime import datetime
-from typing import AsyncGenerator, BinaryIO, List, Optional, Union
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, BinaryIO
 
 import hydrogram
-from hydrogram import enums, raw, types, utils
+from hydrogram import enums, filters, raw, types, utils
+from hydrogram.types import ListenerTypes
 from hydrogram.types.object import Object
 
+if TYPE_CHECKING:
+    from collections.abc import AsyncGenerator
+    from datetime import datetime
+
 
 class Chat(Object):
     """A chat.
@@ -38,6 +44,9 @@ class Chat(Object):
         is_verified (``bool``, *optional*):
             True, if this chat has been verified by Telegram. Supergroups, channels and bots only.
 
+        is_participants_hidden (``bool``, *optional*):
+            True, if this chat members has been hidden.
+
         is_restricted (``bool``, *optional*):
             True, if this chat has been restricted. Supergroups, channels and bots only.
             See *restriction_reason* for details.
@@ -106,6 +115,9 @@ class Chat(Object):
             Pinned message, for groups, supergroups channels and own chat.
             Returned only in :meth:`~hydrogram.Client.get_chat`.
 
+        background (:obj:`~hydrogram.types.ChatBackground`, *optional*):
+            A chat background.
+
         sticker_set_name (``str``, *optional*):
             For supergroups, name of group sticker set.
             Returned only in :meth:`~hydrogram.Client.get_chat`.
@@ -145,44 +157,47 @@ class Chat(Object):
     def __init__(
         self,
         *,
-        client: "hydrogram.Client" = None,
+        client: hydrogram.Client = None,
         id: int,
-        type: "enums.ChatType",
-        is_verified: Optional[bool] = None,
-        is_restricted: Optional[bool] = None,
-        is_creator: Optional[bool] = None,
-        is_scam: Optional[bool] = None,
-        is_fake: Optional[bool] = None,
-        is_support: Optional[bool] = None,
-        is_forum: Optional[bool] = None,
-        title: Optional[str] = None,
-        username: Optional[str] = None,
-        active_usernames: Optional[str] = None,
-        usernames: Optional[List["types.Username"]] = None,
-        first_name: Optional[str] = None,
-        last_name: Optional[str] = None,
-        photo: "types.ChatPhoto" = None,
-        bio: Optional[str] = None,
-        description: Optional[str] = None,
-        dc_id: Optional[int] = None,
-        has_protected_content: Optional[bool] = None,
-        invite_link: Optional[str] = None,
-        pinned_message=None,
-        sticker_set_name: Optional[str] = None,
-        can_set_sticker_set: Optional[bool] = None,
-        members_count: Optional[int] = None,
-        restrictions: Optional[List["types.Restriction"]] = None,
-        permissions: "types.ChatPermissions" = None,
-        distance: Optional[int] = None,
-        linked_chat: "types.Chat" = None,
-        send_as_chat: "types.Chat" = None,
-        available_reactions: Optional["types.ChatReactions"] = None,
+        type: enums.ChatType,
+        is_verified: bool | None = None,
+        is_participants_hidden: bool | None = None,
+        is_restricted: bool | None = None,
+        is_creator: bool | None = None,
+        is_scam: bool | None = None,
+        is_fake: bool | None = None,
+        is_support: bool | None = None,
+        is_forum: bool | None = None,
+        title: str | None = None,
+        username: str | None = None,
+        active_usernames: str | None = None,
+        usernames: list[types.Username] | None = None,
+        first_name: str | None = None,
+        last_name: str | None = None,
+        photo: types.ChatPhoto = None,
+        bio: str | None = None,
+        description: str | None = None,
+        dc_id: int | None = None,
+        has_protected_content: bool | None = None,
+        invite_link: str | None = None,
+        pinned_message: types.Message | None = None,
+        background: types.ChatBackground | None = None,
+        sticker_set_name: str | None = None,
+        can_set_sticker_set: bool | None = None,
+        members_count: int | None = None,
+        restrictions: list[types.Restriction] | None = None,
+        permissions: types.ChatPermissions = None,
+        distance: int | None = None,
+        linked_chat: types.Chat = None,
+        send_as_chat: types.Chat = None,
+        available_reactions: types.ChatReactions | None = None,
     ):
         super().__init__(client)
 
         self.id = id
         self.type = type
         self.is_verified = is_verified
+        self.is_participants_hidden = is_participants_hidden
         self.is_restricted = is_restricted
         self.is_creator = is_creator
         self.is_scam = is_scam
@@ -202,6 +217,7 @@ class Chat(Object):
         self.has_protected_content = has_protected_content
         self.invite_link = invite_link
         self.pinned_message = pinned_message
+        self.background = background
         self.sticker_set_name = sticker_set_name
         self.can_set_sticker_set = can_set_sticker_set
         self.members_count = members_count
@@ -217,7 +233,7 @@ class Chat(Object):
         return " ".join(filter(None, [self.first_name, self.last_name])) or None
 
     @staticmethod
-    def _parse_user_chat(client, user: raw.types.User) -> "Chat":
+    def _parse_user_chat(client, user: raw.types.User) -> Chat:
         peer_id = user.id
 
         return Chat(
@@ -229,9 +245,9 @@ class Chat(Object):
             is_fake=getattr(user, "fake", None),
             is_support=getattr(user, "support", None),
             username=user.usernames[0].username if user.usernames else user.username,
-            active_usernames=types.List(
-                [username.username for username in user.usernames if username.active]
-            )
+            active_usernames=types.List([
+                username.username for username in user.usernames if username.active
+            ])
             or None,
             usernames=types.List([types.Username._parse(r) for r in user.usernames]) or None,
             first_name=user.first_name,
@@ -244,7 +260,7 @@ class Chat(Object):
         )
 
     @staticmethod
-    def _parse_chat_chat(client, chat: raw.types.Chat) -> "Chat":
+    def _parse_chat_chat(client, chat: raw.types.Chat) -> Chat:
         peer_id = -chat.id
         usernames = getattr(chat, "usernames", [])
 
@@ -263,50 +279,41 @@ class Chat(Object):
         )
 
     @staticmethod
-    def _parse_channel_chat(client, channel: raw.types.Channel) -> "Chat":
+    def _parse_channel_chat(client, channel: raw.types.Channel) -> Chat:
         peer_id = utils.get_channel_id(channel.id)
-        restriction_reason = getattr(channel, "restriction_reason", [])
-        usernames = getattr(channel, "usernames", [])
 
         return Chat(
             id=peer_id,
-            type=enums.ChatType.SUPERGROUP
-            if getattr(channel, "megagroup", None)
-            else enums.ChatType.CHANNEL,
-            is_verified=getattr(channel, "verified", None),
-            is_restricted=getattr(channel, "restricted", None),
-            is_creator=getattr(channel, "creator", None),
-            is_scam=getattr(channel, "scam", None),
-            is_fake=getattr(channel, "fake", None),
-            is_forum=getattr(channel, "forum", None),
+            type=enums.ChatType.SUPERGROUP if channel.megagroup else enums.ChatType.CHANNEL,
+            is_verified=channel.verified,
+            is_restricted=channel.restricted,
+            is_creator=channel.creator,
+            is_scam=channel.scam,
+            is_fake=channel.fake,
+            is_forum=channel.forum,
             title=channel.title,
-            username=getattr(channel, "username", None),
-            photo=types.ChatPhoto._parse(
-                client,
-                getattr(channel, "photo", None),
-                peer_id,
-                getattr(channel, "access_hash", 0),
-            ),
-            restrictions=types.List([types.Restriction._parse(r) for r in restriction_reason])
+            username=channel.username,
+            photo=types.ChatPhoto._parse(client, channel.photo, peer_id, channel.access_hash),
+            restrictions=types.List([
+                types.Restriction._parse(r) for r in channel.restriction_reason
+            ])
             or None,
-            permissions=types.ChatPermissions._parse(
-                getattr(channel, "default_banned_rights", None)
-            ),
-            members_count=getattr(channel, "participants_count", None),
-            dc_id=getattr(getattr(channel, "photo", None), "dc_id", None),
-            has_protected_content=getattr(channel, "noforwards", None),
-            usernames=types.List([types.Username._parse(r) for r in usernames]) or None,
+            permissions=types.ChatPermissions._parse(channel.default_banned_rights),
+            members_count=channel.participants_count,
+            dc_id=getattr(channel.photo, "dc_id", None),
+            has_protected_content=channel.noforwards,
+            usernames=types.List([types.Username._parse(r) for r in channel.usernames]) or None,
             client=client,
         )
 
     @staticmethod
     def _parse(
         client,
-        message: Union[raw.types.Message, raw.types.MessageService],
+        message: raw.types.Message | raw.types.MessageService,
         users: dict,
         chats: dict,
         is_chat: bool,
-    ) -> "Chat":
+    ) -> Chat:
         from_id = utils.get_raw_peer_id(message.from_id)
         peer_id = utils.get_raw_peer_id(message.peer_id)
         chat_id = (peer_id or from_id) if is_chat else (from_id or peer_id)
@@ -329,8 +336,8 @@ class Chat(Object):
 
     @staticmethod
     async def _parse_full(
-        client, chat_full: Union[raw.types.messages.ChatFull, raw.types.users.UserFull]
-    ) -> "Chat":
+        client, chat_full: raw.types.messages.ChatFull | raw.types.users.UserFull
+    ) -> Chat:
         users = {u.id: u for u in chat_full.users}
         chats = {c.id: c for c in chat_full.chats}
 
@@ -344,6 +351,9 @@ class Chat(Object):
                 parsed_chat.pinned_message = await client.get_messages(
                     parsed_chat.id, message_ids=full_user.pinned_msg_id
                 )
+
+            if getattr(full_user, "wallpaper", None):
+                parsed_chat.background = types.ChatBackground._parse(client, full_user.wallpaper)
         else:
             full_chat = chat_full.full_chat
             chat_raw = chats[full_chat.id]
@@ -358,6 +368,9 @@ class Chat(Object):
                 # TODO: Add StickerSet type
                 parsed_chat.can_set_sticker_set = full_chat.can_set_stickers
                 parsed_chat.sticker_set_name = getattr(full_chat.stickerset, "short_name", None)
+                parsed_chat.is_participants_hidden = getattr(
+                    full_chat, "participants_hidden", False
+                )
 
                 if linked_chat_raw := chats.get(full_chat.linked_chat_id):
                     parsed_chat.linked_chat = Chat._parse_channel_chat(client, linked_chat_raw)
@@ -370,6 +383,9 @@ class Chat(Object):
 
                     parsed_chat.send_as_chat = Chat._parse_chat(client, send_as_raw)
 
+            if getattr(full_chat, "wallpaper", None):
+                parsed_chat.background = types.ChatBackground._parse(client, full_chat.wallpaper)
+
             parsed_chat.description = full_chat.about or None
 
             if full_chat.pinned_msg_id:
@@ -387,15 +403,194 @@ class Chat(Object):
         return parsed_chat
 
     @staticmethod
-    def _parse_chat(
-        client, chat: Union[raw.types.Chat, raw.types.User, raw.types.Channel]
-    ) -> "Chat":
+    def _parse_chat(client, chat: raw.types.Chat | raw.types.User | raw.types.Channel) -> Chat:
         if isinstance(chat, raw.types.Chat):
             return Chat._parse_chat_chat(client, chat)
         if isinstance(chat, raw.types.User):
             return Chat._parse_user_chat(client, chat)
         return Chat._parse_channel_chat(client, chat)
 
+    def listen(
+        self,
+        filters: filters.Filter | None = None,
+        listener_type: ListenerTypes = ListenerTypes.MESSAGE,
+        timeout: int | None = None,
+        unallowed_click_alert: bool = True,
+        user_id: int | str | list[int | str] | None = None,
+        message_id: int | list[int] | None = None,
+        inline_message_id: str | list[str] | None = None,
+    ):
+        """
+        Bound method *listen* of :obj:`~hydrogram.types.Chat`.
+
+        Use as a shortcut for:
+
+        .. code-block:: python
+
+            await client.listen(chat_id=chat_id)
+
+        Example:
+            .. code-block:: python
+
+                await chat.listen()
+
+        Parameters:
+            filters (``Optional[filters.Filter]``):
+                A filter to check if the listener should be fulfilled.
+
+            listener_type (``ListenerTypes``):
+                The type of listener to create. Defaults to :attr:`hydrogram.types.ListenerTypes.MESSAGE`.
+
+            timeout (``Optional[int]``):
+                The maximum amount of time to wait for the listener to be fulfilled. Defaults to ``None``.
+
+            unallowed_click_alert (``bool``):
+                Whether to alert the user if they click on a button that is not intended for them. Defaults to ``True``.
+
+            user_id (``Optional[Union[int, str], List[Union[int, str]]]``):
+                The user ID(s) to listen for. Defaults to ``None``.
+
+            message_id (``Optional[Union[int, List[int]]]``):
+                The message ID(s) to listen for. Defaults to ``None``.
+
+            inline_message_id (``Optional[Union[str, List[str]]]``):
+                The inline message ID(s) to listen for. Defaults to ``None``.
+
+        Returns:
+            Union[:obj:`~hydrogram.types.Message`, :obj:`~hydrogram.types.CallbackQuery`]: The Message or CallbackQuery
+        """
+        return self._client.listen(
+            chat_id=self.id,
+            filters=filters,
+            listener_type=listener_type,
+            timeout=timeout,
+            unallowed_click_alert=unallowed_click_alert,
+            user_id=user_id,
+            message_id=message_id,
+            inline_message_id=inline_message_id,
+        )
+
+    def ask(
+        self,
+        text: str,
+        filters: filters.Filter | None = None,
+        listener_type: ListenerTypes = ListenerTypes.MESSAGE,
+        timeout: int | None = None,
+        unallowed_click_alert: bool = True,
+        user_id: int | str | list[int | str] | None = None,
+        message_id: int | list[int] | None = None,
+        inline_message_id: str | list[str] | None = None,
+        *args,
+        **kwargs,
+    ):
+        """
+        Bound method *ask* of :obj:`~hydrogram.types.Chat`.
+
+        Use as a shortcut for:
+
+        .. code-block:: python
+
+            await client.ask(chat_id=chat_id, text=text)
+
+        Example:
+
+            .. code-block:: python
+
+                await chat.ask("What's your name?")
+
+        Parameters:
+            text (``str``):
+                The text to send.
+
+            filters (``Optional[filters.Filter]``):
+                Same as :meth:`hydrogram.Client.listen`.
+
+            listener_type (``ListenerTypes``):
+                Same as :meth:`hydrogram.Client.listen`.
+
+            timeout (``Optional[int]``):
+                Same as :meth:`hydrogram.Client.listen`.
+
+            unallowed_click_alert (``bool``):
+                Same as :meth:`hydrogram.Client.listen`.
+
+            user_id (``Optional[Union[int, str], List[Union[int, str]]]``):
+                The user ID(s) to listen for. Defaults to ``None``.
+
+            message_id (``Optional[Union[int, List[int]]]``):
+                The message ID(s) to listen for. Defaults to ``None``.
+
+            inline_message_id (``Optional[Union[str, List[str]]]``):
+                The inline message ID(s) to listen for. Defaults to ``None``.
+
+            args (``Any``):
+                Additional arguments to pass to :meth:`hydrogram.Client.send_message`.
+
+            kwargs (``Any``):
+                Additional keyword arguments to pass to :meth:`hydrogram.Client.send_message`.
+
+        Returns:
+            Union[:obj:`~hydrogram.types.Message`, :obj:`~hydrogram.types.CallbackQuery`]: The Message or CallbackQuery
+        """
+        return self._client.ask(
+            chat_id=self.id,
+            text=text,
+            filters=filters,
+            listener_type=listener_type,
+            timeout=timeout,
+            unallowed_click_alert=unallowed_click_alert,
+            user_id=user_id,
+            message_id=message_id,
+            inline_message_id=inline_message_id,
+            *args,
+            **kwargs,
+        )
+
+    def stop_listening(
+        self,
+        listener_type: ListenerTypes = ListenerTypes.MESSAGE,
+        user_id: int | str | list[int | str] | None = None,
+        message_id: int | list[int] | None = None,
+        inline_message_id: str | list[str] | None = None,
+    ):
+        """
+        Bound method *stop_listening* of :obj:`~hydrogram.types.Chat`.
+
+        Use as a shortcut for:
+
+        .. code-block:: python
+
+            await client.stop_listening(chat_id=chat_id)
+
+        Example:
+            .. code-block:: python
+
+                await chat.stop_listening()
+
+        Parameters:
+            listener_type (``ListenerTypes``):
+                The type of listener to stop listening for. Defaults to :attr:`hydrogram.types.ListenerTypes.MESSAGE`.
+
+            user_id (``Optional[Union[int, str], List[Union[int, str]]]``):
+                The user ID(s) to stop listening for. Defaults to ``None``.
+
+            message_id (``Optional[Union[int, List[int]]]``):
+                The message ID(s) to stop listening for. Defaults to ``None``.
+
+            inline_message_id (``Optional[Union[str, List[str]]]``):
+                The inline message ID(s) to stop listening for. Defaults to ``None``.
+
+        Returns:
+            ``bool``: The return value of :meth:`hydrogram.Client.stop_listening`.
+        """
+        return self._client.stop_listening(
+            chat_id=self.id,
+            listener_type=listener_type,
+            user_id=user_id,
+            message_id=message_id,
+            inline_message_id=inline_message_id,
+        )
+
     async def archive(self):
         """Bound method *archive* of :obj:`~hydrogram.types.Chat`.
 
@@ -403,7 +598,7 @@ class Chat(Object):
 
         .. code-block:: python
 
-            await client.archive_chats(-100123456789)
+            await client.archive_chats(chat_id=chat_id)
 
         Example:
             .. code-block:: python
@@ -426,7 +621,7 @@ class Chat(Object):
 
         .. code-block:: python
 
-            await client.unarchive_chats(-100123456789)
+            await client.unarchive_chats(chat_id=chat_id)
 
         Example:
             .. code-block:: python
@@ -450,10 +645,7 @@ class Chat(Object):
 
         .. code-block:: python
 
-            await client.set_chat_title(
-                chat_id=chat_id,
-                title=title
-            )
+            await client.set_chat_title(chat_id=chat_id, title=title)
 
         Example:
             .. code-block:: python
@@ -485,10 +677,7 @@ class Chat(Object):
 
         .. code-block:: python
 
-            await client.set_chat_description(
-                chat_id=chat_id,
-                description=description
-            )
+            await client.set_chat_description(chat_id=chat_id, description=description)
 
         Example:
             .. code-block:: python
@@ -512,9 +701,9 @@ class Chat(Object):
     async def set_photo(
         self,
         *,
-        photo: Optional[Union[str, BinaryIO]] = None,
-        video: Optional[Union[str, BinaryIO]] = None,
-        video_start_ts: Optional[float] = None,
+        photo: str | BinaryIO | None = None,
+        video: str | BinaryIO | None = None,
+        video_start_ts: float | None = None,
     ) -> bool:
         """Bound method *set_photo* of :obj:`~hydrogram.types.Chat`.
 
@@ -522,10 +711,7 @@ class Chat(Object):
 
         .. code-block:: python
 
-            await client.set_chat_photo(
-                chat_id=chat_id,
-                photo=photo
-            )
+            await client.set_chat_photo(chat_id=chat_id, photo=photo)
 
         Example:
             .. code-block:: python
@@ -570,18 +756,15 @@ class Chat(Object):
         )
 
     async def ban_member(
-        self, user_id: Union[int, str], until_date: datetime = utils.zero_datetime()
-    ) -> Union["types.Message", bool]:
+        self, user_id: int | str, until_date: datetime = utils.zero_datetime()
+    ) -> types.Message | bool:
         """Bound method *ban_member* of :obj:`~hydrogram.types.Chat`.
 
         Use as a shortcut for:
 
         .. code-block:: python
 
-            await client.ban_chat_member(
-                chat_id=chat_id,
-                user_id=user_id
-            )
+            await client.ban_chat_member(chat_id=chat_id, user_id=user_id)
 
         Example:
             .. code-block:: python
@@ -615,17 +798,14 @@ class Chat(Object):
             chat_id=self.id, user_id=user_id, until_date=until_date
         )
 
-    async def unban_member(self, user_id: Union[int, str]) -> bool:
+    async def unban_member(self, user_id: int | str) -> bool:
         """Bound method *unban_member* of :obj:`~hydrogram.types.Chat`.
 
         Use as a shortcut for:
 
         .. code-block:: python
 
-            await client.unban_chat_member(
-                chat_id=chat_id,
-                user_id=user_id
-            )
+            await client.unban_chat_member(chat_id=chat_id, user_id=user_id)
 
         Example:
             .. code-block:: python
@@ -651,10 +831,10 @@ class Chat(Object):
 
     async def restrict_member(
         self,
-        user_id: Union[int, str],
-        permissions: "types.ChatPermissions",
+        user_id: int | str,
+        permissions: types.ChatPermissions,
         until_date: datetime = utils.zero_datetime(),
-    ) -> "types.Chat":
+    ) -> types.Chat:
         """Bound method *unban_member* of :obj:`~hydrogram.types.Chat`.
 
         Use as a shortcut for:
@@ -662,9 +842,7 @@ class Chat(Object):
         .. code-block:: python
 
             await client.restrict_chat_member(
-                chat_id=chat_id,
-                user_id=user_id,
-                permissions=ChatPermissions()
+                chat_id=chat_id, user_id=user_id, permissions=ChatPermissions()
             )
 
         Example:
@@ -702,7 +880,7 @@ class Chat(Object):
     # Set None as privileges default due to issues with partially initialized module, because at the time Chat
     # is being initialized, ChatPrivileges would be required here, but was not initialized yet.
     async def promote_member(
-        self, user_id: Union[int, str], privileges: "types.ChatPrivileges" = None
+        self, user_id: int | str, privileges: types.ChatPrivileges = None
     ) -> bool:
         """Bound method *promote_member* of :obj:`~hydrogram.types.Chat`.
 
@@ -710,10 +888,7 @@ class Chat(Object):
 
         .. code-block:: python
 
-            await client.promote_chat_member(
-                chat_id=chat_id,
-                user_id=user_id
-            )
+            await client.promote_chat_member(chat_id=chat_id, user_id=user_id)
 
         Example:
 
@@ -811,18 +986,15 @@ class Chat(Object):
 
     async def get_member(
         self,
-        user_id: Union[int, str],
-    ) -> "types.ChatMember":
+        user_id: int | str,
+    ) -> types.ChatMember:
         """Bound method *get_member* of :obj:`~hydrogram.types.Chat`.
 
         Use as a shortcut for:
 
         .. code-block:: python
 
-            await client.get_chat_member(
-                chat_id=chat_id,
-                user_id=user_id
-            )
+            await client.get_chat_member(chat_id=chat_id, user_id=user_id)
 
         Example:
             .. code-block:: python
@@ -839,8 +1011,8 @@ class Chat(Object):
         self,
         query: str = "",
         limit: int = 0,
-        filter: "enums.ChatMembersFilter" = enums.ChatMembersFilter.SEARCH,
-    ) -> Optional[AsyncGenerator["types.ChatMember", None]]:
+        filter: enums.ChatMembersFilter = enums.ChatMembersFilter.SEARCH,
+    ) -> AsyncGenerator[types.ChatMember, None] | None:
         """Bound method *get_members* of :obj:`~hydrogram.types.Chat`.
 
         Use as a shortcut for:
@@ -879,7 +1051,7 @@ class Chat(Object):
 
     async def add_members(
         self,
-        user_ids: Union[Union[int, str], List[Union[int, str]]],
+        user_ids: int | str | list[int | str],
         forward_limit: int = 100,
     ) -> bool:
         """Bound method *add_members* of :obj:`~hydrogram.types.Chat`.
