@@ -1,5 +1,5 @@
 #  Hydrogram - Telegram MTProto API Client Library for Python
-#  Copyright (C) 2023-present Amano LLC <https://amanoteam.com>
+#  Copyright (C) 2023-present Hydrogram <https://hydrogram.org>
 #
 #  This file is part of Hydrogram.
 #
@@ -16,9 +16,13 @@
 #  You should have received a copy of the GNU Lesser General Public License
 #  along with Hydrogram.  If not, see <http://www.gnu.org/licenses/>.
 
-from hydrogram import raw
+from typing import TYPE_CHECKING
+
 from hydrogram.types.object import Object
 
+if TYPE_CHECKING:
+    from hydrogram import raw
+
 
 class PeerUser(Object):
     """A PeerUser.
